==> pinocchio-3.3.0.x86_64_linux.bottle.tar.gz: pinocchio/3.3.0/lib/cmake/pinocchio/pinocchioTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pinocchio::pinocchio_default" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_default APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_default PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpinocchio_default.so.3.3.0"
  IMPORTED_SONAME_RELEASE "libpinocchio_default.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_default )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_default "${_IMPORT_PREFIX}/lib/libpinocchio_default.so.3.3.0" )

# Import target "pinocchio::pinocchio_collision" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_collision APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_collision PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpinocchio_collision.so.3.3.0"
  IMPORTED_SONAME_RELEASE "libpinocchio_collision.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_collision )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_collision "${_IMPORT_PREFIX}/lib/libpinocchio_collision.so.3.3.0" )

# Import target "pinocchio::pinocchio_parsers" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_parsers APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_parsers PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpinocchio_parsers.so.3.3.0"
  IMPORTED_SONAME_RELEASE "libpinocchio_parsers.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_parsers )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_parsers "${_IMPORT_PREFIX}/lib/libpinocchio_parsers.so.3.3.0" )

# Import target "pinocchio::pinocchio_pywrap_default" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_pywrap_default APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_pywrap_default PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/pinocchio/3.3.0/lib/python3.12/site-packages/pinocchio/pinocchio_pywrap_default.cpython-312-x86_64-linux-gnu.so.3.3.0"
  IMPORTED_SONAME_RELEASE "pinocchio_pywrap_default.cpython-312-x86_64-linux-gnu.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_pywrap_default )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_pywrap_default "@@HOMEBREW_CELLAR@@/pinocchio/3.3.0/lib/python3.12/site-packages/pinocchio/pinocchio_pywrap_default.cpython-312-x86_64-linux-gnu.so.3.3.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> pinocchio-3.3.0_1.x86_64_linux.bottle.tar.gz: pinocchio/3.3.0_1/lib/cmake/pinocchio/pinocchioTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pinocchio::pinocchio_default" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_default APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_default PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpinocchio_default.so.3.3.0"
  IMPORTED_SONAME_RELEASE "libpinocchio_default.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_default )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_default "${_IMPORT_PREFIX}/lib/libpinocchio_default.so.3.3.0" )

# Import target "pinocchio::pinocchio_collision" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_collision APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_collision PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpinocchio_collision.so.3.3.0"
  IMPORTED_SONAME_RELEASE "libpinocchio_collision.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_collision )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_collision "${_IMPORT_PREFIX}/lib/libpinocchio_collision.so.3.3.0" )

# Import target "pinocchio::pinocchio_parsers" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_parsers APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_parsers PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpinocchio_parsers.so.3.3.0"
  IMPORTED_SONAME_RELEASE "libpinocchio_parsers.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_parsers )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_parsers "${_IMPORT_PREFIX}/lib/libpinocchio_parsers.so.3.3.0" )

# Import target "pinocchio::pinocchio_pywrap_default" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_pywrap_default APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_pywrap_default PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/pinocchio/3.3.0_1/lib/python3.12/site-packages/pinocchio/pinocchio_pywrap_default.cpython-312-x86_64-linux-gnu.so.3.3.0"
  IMPORTED_SONAME_RELEASE "pinocchio_pywrap_default.cpython-312-x86_64-linux-gnu.so.3.3.0"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_pywrap_default )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_pywrap_default "@@HOMEBREW_CELLAR@@/pinocchio/3.3.0_1/lib/python3.12/site-packages/pinocchio/pinocchio_pywrap_default.cpython-312-x86_64-linux-gnu.so.3.3.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
